## input: vector of GO terms
## output: heatmap semantic similarity scores
library(tools)
library(GOSemSim)
library(ComplexHeatmap)
library(circlize)
library('BiocParallel')  
library(data.table)
library(tidyverse)

## GO data from mouse org database for biological processes
## Can do for mouse phenotype and molecular processes
mmGO = godata('org.Mm.eg.db', ont="BP") 
plot_dir = ("consensus/promoters/")
## Wang is actually a guy but here it refers to a semantic similarity metric (see https://yulab-smu.top/biomedical-knowledge-mining-book/semantic-similarity-overview.html)
## combine = 'BMA' returns a single value estimating how similar the 2 sets are, you can change it with min,max,avg ... (see link above)

goPCA <- function(fileList, file_to_compare_to){
    files =list.files(fileList, pattern= "", full.names=T) # create list of files in directory
    files = as.list(files)
    list = lapply(files, function(x) read.table(x, header=TRUE, sep="\t", quote = "") %>% as.data.table()) # read in all files
    ## this keeps only the significant GO terms
    significant_go_terms=lapply(list,function(x) x=x[p.adjust<=0.01])
    listVector = lapply(significant_go_terms, function(x) dplyr::pull(x, ID))
    file_input = read.table(file_to_compare_to, sep="\t", header=TRUE, quote="") %>% as.data.frame()
    file_sig_go = dplyr::pull(file_input[file_input$p.adjust <= 0.01,], ID)

    ## This extracts the file names for all the files in the list (all embryonic stages)
    file_names=as.character(list.files(fileList,recursive =F,full.names = F)) ## directory with all embryonic stages
    file_names=gsub("\\..*","",file_names) ## Removes everything except 'E*.5'
    file_names=gsub("[^0-9]","", file_names) ## Removes the 'E' so that it's a number
    names(listVector)=file_names ## Add new names to list

    ## Check if input file name is less than or equal to any in listVector
    ## This will avoid running comparisons that have already been run
    ## Eg. E10.5 vs E11.5 is the same as E11.5 vs E10.5
    file_to_compare_to_name = basename(file_path_sans_ext(file_to_compare_to)) ## Name of file to compare to
    if(grepl('^E', file_to_compare_to_name) == TRUE){ ## If file begins with E (this is so that it doesn't stall with the dunnart files)
        file_to_compare_to_name=gsub("\\..*","",file_to_compare_to_name) ## Removes everything except 'E*.5'
        file_to_compare_to_name=gsub("[^0-9]","",file_to_compare_to_name) ## Removes the 'E' so that it's a number
        listVectorSubset = listVector[names(listVector) > file_to_compare_to_name] ## Keep only vectors in the list that are greater than the file being compared to
                                                                                ## Eg. this means that when comparing E12 to the list then it will only compare to 13,14 & 15
    } else 
    listVectorSubset = listVector

    ## Compare the similarity between GO lists
    ## This will parallelise the lapply function 
    comparisons = bplapply(listVectorSubset,function(x) mgoSim(file_sig_go,x, semData=mmGO,measure="Wang", combine='NULL')) 
    return(comparisons)
}

## This command checks the time it takes to run
## One comparison is about 95 seconds
system.time(mgoSim(listVector[[1]], listVector[[2]],semData=mmGO, measure="Wang", combine='BMA'))

register(SerialParam())


## Promoters
plot_dir = ("consensus/promoters/")

dunnartvsmouse = GOsimilarity(fileList = "consensus/promoters/mouse_GO", 
file_to_compare_to = "consensus/promoters/dunnart_GO/promoter_mm10GOenrich") #dunnart versus all mouse stages

e10vs = GOsimilarity(fileList = "consensus/promoters/mouse_GO", 
file_to_compare_to = "consensus/promoters/mouse_GO/E10.5_promoter_mm10GOenrich") 

e11vs = GOsimilarity(fileList = "consensus/promoters/mouse_GO", 
file_to_compare_to = "consensus/promoters/mouse_GO/E11.5_promoter_mm10GOenrich")

e12vs = GOsimilarity(fileList = "consensus/promoters/mouse_GO", 
file_to_compare_to = "consensus/promoters/mouse_GO/E12.5_promoter_mm10GOenrich") 

e13vs = GOsimilarity(fileList = "consensus/promoters/mouse_GO", 
file_to_compare_to = "consensus/promoters/mouse_GO/E13.5_promoter_mm10GOenrich") 

e14vs = GOsimilarity(fileList = "consensus/promoters/mouse_GO", 
file_to_compare_to = "consensus/promoters/mouse_GO/E14.5_promoter_mm10GOenrich") 


## Enhancers
plot_dir = ("consensus/enhancers/")

dunnartvsmouse = GOsimilarity(fileList = "consensus/enhancers/mouse_GO", 
file_to_compare_to = "consensus/enhancers/dunnart_GO/enhancer_mm10GOenrich_subsample.txt")

e10vs = GOsimilarity(fileList = "consensus/enhancers/mouse_GO", 
file_to_compare_to = "consensus/enhancers/mouse_GO/E10.5_enhancer_mm10GOenrich") #dunnart versus all mouse stages

e11vs = GOsimilarity(fileList = "consensus/enhancers/mouse_GO", 
file_to_compare_to = "consensus/enhancers/mouse_GO/E11.5_enhancer_mm10GOenrich") #dunnart versus all mouse stages

e12vs = GOsimilarity(fileList = "consensus/enhancers/mouse_GO", 
file_to_compare_to = "consensus/enhancers/mouse_GO/E12.5_enhancer_mm10GOenrich") #dunnart versus all mouse stages

e13vs = GOsimilarity(fileList = "consensus/enhancers/mouse_GO", 
file_to_compare_to = "consensus/enhancers/mouse_GO/E13.5_enhancer_mm10GOenrich") #dunnart versus all mouse stages

e14vs = GOsimilarity(fileList = "consensus/enhancers/mouse_GO", 
file_to_compare_to = "consensus/enhancers/mouse_GO/E14.5_enhancer_mm10GOenrich") #dunnart versus all mouse stages

