library(GenomicFeatures)
library(rtracklayer)
library(ChIPseeker)
library(clusterProfiler)
library(org.Mm.eg.db)
library(ChIPpeakAnno)
library(tidyverse)
library(RColorBrewer)
library(ggplot2)
library(data.table)
library(dplyr)
library(TxDb.Mmusculus.UCSC.mm10.ensGene)
###################################################################################################
################################### PEAK ANNOTATION ###############################################
###################################################################################################

## Make txdb for dunnart annotation file
setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/")
smiCra_txdb <- makeTxDbFromGFF("Scras_dunnart_assem1.0_pb-ont-illsr_flyeassem_red-rd-scfitr2_pil2xwgs2_60chr2.gff")


## geneID conversion tables
setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/")
df2 <- read.table("biomart_ensembl.txt", header=TRUE, sep="\t")
df3 <- read.table("bioDBnet_refseq2ensembl_H3K27ac.txt", header=TRUE, sep="\t")


#################################################### DUNNART ANNOTATION ##########################################################

## Anotate peak files
annotatePeaks <- function(peak, outFile, outFile1, annoBar, distanceTSS, heatmapTSS, GOenrich, kegg){
  
  # Annotate peak file based on dunnart GFF
  peakAnno <- annotatePeak(peak, tssRegion = c(-3000, 3000), TxDb = smiCra_txdb)
  
  # Plot annotation
  # pdf(file=annoBar, width=10, height=7)
  # print(plotAnnoBar(peakAnno))
  # dev.off()
  
  # Set promoter range
  # promoter <- getPromoters(TxDb=smiCra_txdb, upstream=3000, downstream=3000)
  
  # Find distance from TSS
  # tagMatrix <- getTagMatrix(toGRanges(peak), windows=promoter)
  
  # Plot heatmap on peak distance to TSS
  # pdf(file=heatmapTSS, width=10, height=7)
  # print(tagHeatmap(tagMatrix, xlim=c(-3000, 3000), color = "#6699CC"))
  # dev.off()

  # Plot distance from TSS
  # pdf(file=distanceTSS, width=10, height=7)
  # print(plotAvgProf(tagMatrix, xlim=c(-3000, 3000)))
  # dev.off()

  # Write annotation to file
  write.table(peakAnno, outFile, sep="\t", quote=F, row.names=F)
  
  peakAnnoDF <- as.data.frame(peakAnno, row.names = NULL)
  # Convert refseq IDs and geneIDs to devil ensembl IDs
  peakAnnoDF$ensemblgeneID <- df2$Gene.stable.ID[match(unlist(peakAnnoDF$geneId), df2$Gene.name)]
  peakAnnoDF$transcriptIdAltered <- gsub("\\..*","", peakAnnoDF$transcriptId)
  peakAnnoDF$refseqID <- df3$Ensembl.Gene.ID[match(unlist(peakAnnoDF$transcriptIdAltered), df3$RefSeq.mRNA.Accession)]
  peakAnnoDF$combined <- ifelse(peakAnnoDF$refseqID == "-", peakAnnoDF$ensemblgeneID, peakAnnoDF$refseqID)
  peakAnnoDF$refseqID[peakAnnoDF$refseqID == as.character("-")] <- NA
  
  # Convert devil ensembl to mouse ensembl
  peakAnnoDF$mouseensembl <- df2$Mouse.gene.stable.ID[match(unlist(peakAnnoDF$combined), df2$Gene.stable.ID)]
  # Write annotation with converted IDs 
  peakAnnoDF <- peakAnnoDF[!is.na(peakAnnoDF$mouseensembl),]
  write.table(peakAnnoDF, outFile1, sep="\t", quote=F, row.names=F)

  # GO enrichment analysis
  GO <- enrichGO(gene = peakAnnoDF$mouseensembl,
                 keyType = "ENSEMBL",
                 OrgDb = org.Mm.eg.db,
                 ont = "BP",
                 pAdjustMethod = "BH",
                 qvalueCutoff = 0.05,
                 readable = TRUE)
  write.table(GO, GOenrich, sep="\t", quote=F, row.names=F)
  
  ## convert mouse ensembl to entrezID
  suppressWarnings(gene.df <- bitr(geneID=peakAnnoDF$mouseensembl, fromType="ENSEMBL", toType="ENTREZID", OrgDb="org.Mm.eg.db" ))
  
  ## kegg analysis
  kk <- enrichKEGG(gene = gene.df$ENTREZID, organism = "mmu", pvalueCutoff=0.05)
  write.table(kk, kegg, sep="\t", quote=F, row.names=F)
}


### Consensus peaks
setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/consensus/enhancers/")
annotatePeaks(peak = "dunnart_enhancer_peaks_subsample.narrowPeak", outFile = "dunnart_enhancer_annotation_subsample.txt", annoBar = "dunnart_enhancer_annoBar_subsample.pdf", distanceTSS = "dunnart_enhancer_distanceTSS_subsample.pdf", heatmapTSS = "dunnart_enhancer_heatmapTSS_subsample.pdf", outFile1 = "dunnart_enhancer_annotationConvertedIDs_subsample.txt", GOenrich = "enhancer_mm10GOenrich_subsample.txt", kegg="enhancer_KEGG_subsample.txt")

setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/consensus/clustered")
annotatePeaks(peak = "dunnart_promoter_peaks_subsample.narrowPeak", outFile = "dunnart_promoter_annotation_subsample.txt", annoBar = "dunnart_promoter_annoBar_subsample.pdf", distanceTSS = "dunnart_promoter_distanceTSS_subsample.pdf", heatmapTSS = "dunnart_promoter_heatmapTSS_subsample.pdf", outFile1 = "dunnart_promoter_annotationConvertedIDs_subsample.txt" , GOenrich = "promoter_mm10GOenrich_subsample.txt", kegg="promoter_KEGG_subsample.txt")

setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/consensus/H3K4me3/")
annotatePeaks(peak = "H3K4me3_overlap_default.narrowPeak", outFile = "H3K4me3_overlap_annotation.txt", annoBar = "H3K4me3_overlap_annoBar.pdf", distanceTSS = "H3K4me3_overlap_distanceTSS.pdf", heatmapTSS = "H3K4me3_overlap_heatmapTSS.pdf", outFile1 = "H3K4me3_overlap_annotationConvertedIDs.txt", GOenrich = "H3K4me3_overlap_mm10GOenrich", kegg="H3K4me3_overlap_KEGG.txt")

setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/consensus/H3K27ac/")
annotatePeaks(peak = "H3K27ac_overlap_default.narrowPeak", outFile = "H3K27ac_overlap_annotation.txt", annoBar = "H3K27ac_overlap_annoBar.pdf", distanceTSS = "H3K27ac_overlap_distanceTSS.pdf", heatmapTSS = "H3K27ac_overlap_heatmapTSS.pdf", outFile1 = "H3K27ac_overlap_annotationConvertedIDs.txt" , GOenrich = "H3K27ac_overlap_mm10GOenrich", kegg="H3K27ac_overlap_KEGG.txt")

annotatePeaks(peak = "consensus/promoters/dunnart.clustered.narrowPeak", outFile = "cluster1_promoter_annotation.txt", annoBar = "cluster1_promoter_annoBar.pdf", distanceTSS = "cluster1_promoter_distanceTSS.pdf", heatmapTSS = "cluster1_promoter_heatmapTSS.pdf", outFile1 = "cluster1_promoter_annotationConvertedIDs.txt" , GOenrich = "cluster1_mm10GOenrich.txt", kegg="cluster1_KEGG.txt")
annotatePeaks(peak = "consensus/promoters/cluster2_promoters.narrowPeak", outFile = "cluster2_promoter_annotation.txt", annoBar = "cluster2_promoter_annoBar.pdf", distanceTSS = "cluster2_promoter_distanceTSS.pdf", heatmapTSS = "cluster2_promoter_heatmapTSS.pdf", outFile1 = "cluster2_promoter_annotationConvertedIDs.txt" , GOenrich = "cluster2_mm10GOenrich.txt", kegg="cluster2_KEGG.txt")
annotatePeaks(peak = "consensus/promoters/cluster3_promoters.narrowPeak", outFile = "cluster3_promoter_annotation.txt", annoBar = "cluster3_promoter_annoBar.pdf", distanceTSS = "cluster3_promoter_distanceTSS.pdf", heatmapTSS = "cluster3_promoter_heatmapTSS.pdf", outFile1 = "cluster3_promoter_annotationConvertedIDs.txt" , GOenrich = "cluster3_mm10GOenrich.txt", kegg="cluster3_KEGG.txt")


### Replicates
setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/replicates/H3K4me3/")
annotatePeaks(peak = "A-2_H3K4me3_vs_A-1_input_macs2_default_peaks.narrowPeak", annoBar = "A-2_H3K4me3_annoBar.pdf", distanceTSS = "A-2_H3K4me3_distanceTSS.pdf", heatmapTSS = "A-2_H3K4me3_heatmapTSS.pdf", outFile = "A-2_H3K4me3_annotation.txt",  outFile1 = "A-2_H3K4me3_annotationConvertedIDs.txt", GOenrich = "A-2_H3K4me3_mm10GOenrich", kegg="A-2_H3K4me3_KEGG.txt")
annotatePeaks(peak = "B-2_H3K4me3_vs_B-1_input_macs2_default_peaks.narrowPeak", annoBar = "B-2_H3K4me3_annoBar.pdf", distanceTSS = "B-2_H3K4me3_distanceTSS.pdf", heatmapTSS = "B-2_H3K4me3_heatmapTSS.pdf", outFile = "B-2_H3K4me3_annotation.txt",  outFile1 = "B-2_H3K4me3_annotationConvertedIDs.txt", GOenrich = "B-2_H3K4me3_mm10GOenrich", kegg="B-2_H3K4me3_KEGG.txt")
setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/replicates/H3K27ac/")
annotatePeaks(peak = "A-3_H3K27ac_vs_A-1_input_macs2_default_peaks.narrowPeak", annoBar = "A-3_H3K27ac_annoBar.pdf", distanceTSS = "A-3_H3K27ac_distanceTSS.pdf", heatmapTSS = "A-3_H3K27ac_heatmapTSS.pdf", outFile = "A-3_H3K27ac_annotation.txt",  outFile1 = "A-3_H3K27ac_annotationConvertedIDs.txt", GOenrich = "A-3_H3K27ac_mm10GOenrich", kegg="A-3_H3K27ac_KEGG.txt")
annotatePeaks(peak = "B-3_H3K27ac_vs_B-1_input_macs2_default_peaks.narrowPeak", annoBar = "B-3_H3K27ac_annoBar.pdf", distanceTSS = "B-3_H3K27ac_distanceTSS.pdf", heatmapTSS = "B-3_H3K27ac_heatmapTSS.pdf", outFile = "B-3_H3K27ac_annotation.txt",  outFile1 = "B-3_H3K27ac_annotationConvertedIDs.txt", GOenrich = "B-3_H3K27ac_mm10GOenrich", kegg="B-3_H3K27ac_KEGG.txt")

## Overlaps
setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/overlaps/enhancers")
annotatePeaks(peak = "enhancer_summit100bp_mm10TOsmiCra1.bed", outFile = "enhancer_summit100bp_annotation.txt", annoBar = "enhancer_summit100bp_annoBar.pdf", distanceTSS = "enhancer_summit100bp_distanceTSS.pdf", heatmapTSS = "enhancer_summit100bp_heatmapTSS.pdf", outFile1 = "enhancer_summit100bp_annotationConvertedIDs.txt" , GOenrich = "enhancer_summit100bp_mm10GOenrich", kegg="enhancer_summit100bp_KEGG.txt")

setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/overlaps/promoters")
annotatePeaks(peak = "promoter_summit100bp_mm10TOsmiCra1.bed", outFile = "promoter_summit100bp_annotation.txt", annoBar = "promoter_summit100bp_annoBar.pdf", distanceTSS = "promoter_summit100bp_distanceTSS.pdf", heatmapTSS = "promoter_summit100bp_heatmapTSS.pdf", outFile1 = "promoter_summit100bp_annotationConvertedIDs.txt" , GOenrich = "promoter_summit100bp_mm10GOenrich", kegg="promoter_summit100bp_KEGG.txt")


#################################################### MOUSE ANNOTATION ##########################################################

## Anotate peak files
annotatePeaksmm10 <- function(peak, outFile, annoBar, distanceTSS, heatmapTSS, outFile1, GOenrich, kegg){
  
  # Annotate peak file based on mouse ENSEMBL annotation
  peakAnno <- annotatePeak(peak, tssRegion = c(-3000, 3000), TxDb = TxDb.Mmusculus.UCSC.mm10.ensGene)
  
  # Write annotation to file
  write.table(peakAnno, outFile, sep="\t", quote=F, row.names=F)

  # Set promoter range
  #promoter <- getPromoters(TxDb=TxDb.Mmusculus.UCSC.mm10.ensGene, upstream=3000, downstream=3000)
  
  # Find distance from TSS
  #tagMatrix <- getTagMatrix(peak, windows=promoter)
  
  # Plot annotation
  # pdf(file=annoBar, width=10, height=7)
  # print(plotAnnoBar(peakAnno))
  # dev.off()
  
  # Plot heatmap on peak distance to TSS
  # pdf(file=heatmapTSS, width=10, height=7)
  # print(tagHeatmap(tagMatrix, xlim=c(-3000, 3000), color = "#6699CC"))
  # dev.off()

  # Plot distance from TSS
  # pdf(file=distanceTSS, width=10, height=7)
  # print(plotDistToTSS(peakAnno))
  # dev.off()

  annot <- as.data.frame(peakAnno@anno)
  
  # GO enrichment analysis
  GO <- enrichGO(gene = annot$geneId,
                 keyType = "ENSEMBL",
                 #universe = enh$geneId,
                 OrgDb = org.Mm.eg.db,
                 ont = "BP",
                 pAdjustMethod = "BH",
                 qvalueCutoff = 0.05,
                 readable = TRUE)
  write.table(GO, GOenrich, sep="\t", quote=F, row.names=F)
  
  ## convert mouse ensembl to entrezID
  suppressWarnings(gene.df <- bitr(geneID=annot$geneId, fromType="ENSEMBL", toType="ENTREZID", OrgDb="org.Mm.eg.db" ))
  
  ## kegg analysis
  kk <- enrichKEGG(gene = gene.df$ENTREZID, 
  #universe = enh$geneId, 
  organism = "mmu", pvalueCutoff=0.05)
  write.table(kk, kegg, sep="\t", quote=F, row.names=F)
}


### Consensus peaks
setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/consensus/enhancers/")
annotatePeaksmm10(peak = "E10.5_enhancer_peaks.narrowPeak", outFile = "E10.5_enhancer_annotation.txt", annoBar = "E10.5_enhancer_annoBar.pdf", distanceTSS = "E10.5_enhancer_distanceTSS.pdf", heatmapTSS = "E10.5_enhancer_heatmapTSS.pdf", outFile1 = "E10.5_enhancer_annotationConvertedIDs.txt", GOenrich = "E10.5_enhancer_mm10GOenrich", kegg="E10.5_enhancer_KEGG.txt")
annotatePeaksmm10(peak = "E11.5_enhancer_peaks.narrowPeak", outFile = "E11.5_enhancer_annotation.txt", annoBar = "E11.5_enhancer_annoBar.pdf", distanceTSS = "E11.5_enhancer_distanceTSS.pdf", heatmapTSS = "E11.5_enhancer_heatmapTSS.pdf", outFile1 = "E11.5_enhancer_annotationConvertedIDs.txt", GOenrich = "E11.5_enhancer_mm10GOenrich", kegg="E11.5_enhancer_KEGG.txt")
annotatePeaksmm10(peak = "E12.5_enhancer_peaks.narrowPeak", outFile = "E12.5_enhancer_annotation.txt", annoBar = "E12.5_enhancer_annoBar.pdf", distanceTSS = "E12.5_enhancer_distanceTSS.pdf", heatmapTSS = "E12.5_enhancer_heatmapTSS.pdf",  outFile1 = "E12.5_enhancer_annotationConvertedIDs.txt", GOenrich = "E12.5_enhancer_mm10GOenrich", kegg="E12.5_enhancer_KEGG.txt")
annotatePeaksmm10(peak = "E13.5_enhancer_peaks.narrowPeak", outFile = "E13.5_enhancer_annotation.txt", annoBar = "E13.5_enhancer_annoBar.pdf", distanceTSS = "E13.5_enhancer_distanceTSS.pdf", heatmapTSS = "E13.5_enhancer_heatmapTSS.pdf",  outFile1 = "E13.5_enhancer_annotationConvertedIDs.txt", GOenrich = "E13.5_enhancer_mm10GOenrich", kegg="E13.5_enhancer_KEGG.txt")
annotatePeaksmm10(peak = "E14.5_enhancer_peaks.narrowPeak", outFile = "E14.5_enhancer_annotation.txt", annoBar = "E14.5_enhancer_annoBar.pdf", distanceTSS = "E14.5_enhancer_distanceTSS.pdf", heatmapTSS = "E14.5_enhancer_heatmapTSS.pdf",  outFile1 = "E14.5_enhancer_annotationConvertedIDs.txt", GOenrich = "E14.5_enhancer_mm10GOenrich", kegg="E14.5_enhancer_KEGG.txt")
annotatePeaksmm10(peak = "E15.5_enhancer_peaks.narrowPeak", outFile = "E15.5_enhancer_annotation.txt", annoBar = "E15.5_enhancer_annoBar.pdf", distanceTSS = "E15.5_enhancer_distanceTSS.pdf", heatmapTSS = "E15.5_enhancer_heatmapTSS.pdf",  outFile1 = "E15.5_enhancer_annotationConvertedIDs.txt", GOenrich = "E15.5_enhancer_mm10GOenrich", kegg="E15.5_enhancer_KEGG.txt")
setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/consensus/promoters/")
annotatePeaksmm10(peak = "E10.5_promoter_peaks.narrowPeak", outFile = "E10.5_promoter_annotation.txt", annoBar = "E10.5_promoter_annoBar.pdf", distanceTSS = "E10.5_promoter_distanceTSS.pdf", heatmapTSS = "E10.5_promoter_heatmapTSS.pdf",  GOenrich = "E10.5_promoter_mm10GOenrich", kegg="E10.5_promoter_KEGG.txt")
annotatePeaksmm10(peak = "E11.5_promoter_peaks.narrowPeak", outFile = "E11.5_promoter_annotation.txt", annoBar = "E11.5_promoter_annoBar.pdf", distanceTSS = "E11.5_promoter_distanceTSS.pdf", heatmapTSS = "E11.5_promoter_heatmapTSS.pdf",  GOenrich = "E11.5_promoter_mm10GOenrich", kegg="E11.5_promoter_KEGG.txt")
annotatePeaksmm10(peak = "E12.5_promoter_peaks.narrowPeak", outFile = "E12.5_promoter_annotation.txt", annoBar = "E12.5_promoter_annoBar.pdf", distanceTSS = "E12.5_promoter_distanceTSS.pdf", heatmapTSS = "E12.5_promoter_heatmapTSS.pdf",  GOenrich = "E12.5_promoter_mm10GOenrich", kegg="E12.5_promoter_KEGG.txt")
annotatePeaksmm10(peak = "E13.5_promoter_peaks.narrowPeak", outFile = "E13.5_promoter_annotation.txt", annoBar = "E13.5_promoter_annoBar.pdf", distanceTSS = "E13.5_promoter_distanceTSS.pdf", heatmapTSS = "E13.5_promoter_heatmapTSS.pdf",  GOenrich = "E13.5_promoter_mm10GOenrich", kegg="E13.5_promoter_KEGG.txt")
annotatePeaksmm10(peak = "E14.5_promoter_peaks.narrowPeak", outFile = "E14.5_promoter_annotation.txt", annoBar = "E14.5_promoter_annoBar.pdf", distanceTSS = "E14.5_promoter_distanceTSS.pdf", heatmapTSS = "E14.5_promoter_heatmapTSS.pdf",  GOenrich = "E14.5_promoter_mm10GOenrich", kegg="E14.5_promoter_KEGG.txt")
annotatePeaksmm10(peak = "E15.5_promoter_peaks.narrowPeak", outFile = "E15.5_promoter_annotation.txt", annoBar = "E15.5_promoter_annoBar.pdf", distanceTSS = "E15.5_promoter_distanceTSS.pdf", heatmapTSS = "E15.5_promoter_heatmapTSS.pdf",  GOenrich = "E15.5_promoter_mm10GOenrich", kegg="E15.5_promoter_KEGG.txt")

peakList = "consensus/promoters"
peakFiles = list.files(peakList, pattern= "promoter_peaks.narrowPeak", full.names=T)
peakData = lapply(peakFiles, function(x) fread(x, header=FALSE, sep="\t", quote = "", na.strings=c("", "NA"))) # read in all files
peakData = list(peakData[[1]],peakData[[2]], peakData[[3]], peakData[[4]], peakData[[5]], peakData[[6]], peakData[[7]])
names(peakData) = c("dunnart", "E10.5", "E11.5", "E12.5", "E13.5", "E14.5", "E15.5")

clusterList = "consensus/promoters/clustered"
clusterFiles = list.files(clusterList, pattern= "_annotation.txt", full.names=T)
clusterData = lapply(clusterFiles, function(x) fread(x, header=TRUE, sep="\t", quote = "", na.strings=c("", "NA"))) # read in all files
clusterIDs = lapply(clusterData, function(x) x$V4 %>% as.data.frame())
clusterIDs = rbind(clusterIDs[[1]], clusterIDs[[2]], clusterIDs[[3]], clusterIDs[[4]], clusterIDs[[5]], clusterIDs[[6]], clusterIDs[[7]])
test = as.vector(unlist(clusterIDs))
promoters = lapply(peakData, function(x) x[x$V4 %in% test,])    
lapply(names(promoters), function(x) write.table(promoters[[x]], file=paste(x,"clustered","narrowPeak", sep="."), sep="\t", quote=FALSE, col.names=FALSE, row.names=FALSE))


setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/")
annotatePeaksmm10(peak = "E10.5.clustered.narrowPeak", outFile = "cluster1_E10.5_promoter_annotation.txt", annoBar = "cluster1_E10.5_promoter_annoBar.pdf", distanceTSS = "cluster1_E10.5_promoter_distanceTSS.pdf", heatmapTSS = "cluster1_E10.5_promoter_heatmapTSS.pdf", GOenrich = "cluster1_E10.5_promoter_mm10GOenrich", kegg="cluster1_E10.5_promoter_KEGG.txt")
annotatePeaksmm10(peak = "E11.5.clustered.narrowPeak", outFile = "cluster1_E11.5_promoter_annotation.txt", annoBar = "cluster1_E11.5_promoter_annoBar.pdf", distanceTSS = "cluster1_E11.5_promoter_distanceTSS.pdf", heatmapTSS = "cluster1_E11.5_promoter_heatmapTSS.pdf", GOenrich = "cluster1_E11.5_promoter_mm10GOenrich", kegg="cluster1_E11.5_promoter_KEGG.txt")
annotatePeaksmm10(peak = "E12.5.clustered.narrowPeak", outFile = "cluster1_E12.5_promoter_annotation.txt", annoBar = "cluster1_E12.5_promoter_annoBar.pdf", distanceTSS = "cluster1_E12.5_promoter_distanceTSS.pdf", heatmapTSS = "cluster1_E12.5_promoter_heatmapTSS.pdf", GOenrich = "cluster1_E12.5_promoter_mm10GOenrich", kegg="cluster1_E12.5_promoter_KEGG.txt")
annotatePeaksmm10(peak = "E13.5.clustered.narrowPeak", outFile = "cluster1_E13.5_promoter_annotation.txt", annoBar = "cluster1_E13.5_promoter_annoBar.pdf", distanceTSS = "cluster1_E13.5_promoter_distanceTSS.pdf", heatmapTSS = "cluster1_E13.5_promoter_heatmapTSS.pdf", GOenrich = "cluster1_E13.5_promoter_mm10GOenrich", kegg="cluster1_E13.5_promoter_KEGG.txt")
annotatePeaksmm10(peak = "E14.5.clustered.narrowPeak", outFile = "cluster1_E14.5_promoter_annotation.txt", annoBar = "cluster1_E14.5_promoter_annoBar.pdf", distanceTSS = "cluster1_E14.5_promoter_distanceTSS.pdf", heatmapTSS = "cluster1_E14.5_promoter_heatmapTSS.pdf", GOenrich = "cluster1_E14.5_promoter_mm10GOenrich", kegg="cluster1_E14.5_promoter_KEGG.txt")
annotatePeaksmm10(peak = "E15.5.clustered.narrowPeak", outFile = "cluster1_E15.5_promoter_annotation.txt", annoBar = "cluster1_E15.5_promoter_annoBar.pdf", distanceTSS = "cluster1_E15.5_promoter_distanceTSS.pdf", heatmapTSS = "cluster1_E15.5_promoter_heatmapTSS.pdf", GOenrich = "cluster1_E15.5_promoter_mm10GOenrich", kegg="cluster1_E15.5_promoter_KEGG.txt")




### Replicates
setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/replicates/H3K27ac/")
annotatePeaksmm10(peak = "ENCFF548BRR_vs_ENCFF825AVI_E10.5_H3K27ac_macs2_peaks.narrowPeak", annoBar = "E10.5_ENCFF548BRR_H3K4me3_annoBar.pdf", distanceTSS = "E10.5_ENCFF548BRR_H3K27ac_distanceTSS.pdf", heatmapTSS = "E10.5_ENCFF548BRR_H3K27ac_heatmapTSS.pdf", outFile = "E10.5_ENCFF548BRR_H3K27ac_annotation.txt",   GOenrich = "E10.5_ENCFF548BRR_H3K27ac_mm10GOenrich.txt", kegg="E10.5_ENCFF548BRR_H3K27ac_KEGG.txt")
annotatePeaksmm10(peak = "ENCFF213EBC_vs_ENCFF157KEH_E10.5_H3K27ac_macs2_peaks.narrowPeak", annoBar = "E10.5_ENCFF213EBC_H3K27ac_annoBar.pdf", distanceTSS = "E10.5_ENCFF213EBC_H3K27ac_distanceTSS.pdf", heatmapTSS = "E10.5_ENCFF213EBC_H3K27ac_heatmapTSS.pdf", outFile = "E10.5_ENCFF213EBC_H3K27ac_annotation.txt",  GOenrich = "E10.5_ENCFF213EBC_H3K27ac_mm10GOenrich.txt", kegg="E10.5_ENCFF213EBC_H3K27ac_KEGG.txt")
annotatePeaksmm10(peak = "ENCFF512SFE_vs_ENCFF184CUE_E11.5_H3K27ac_macs2_peaks.narrowPeak", annoBar = "E11.5_ENCFF512SFE_H3K27ac_annoBar.pdf", distanceTSS = "E11.5_ENCFF512SFE_H3K27ac_distanceTSS.pdf", heatmapTSS = "E11.5_ENCFF512SFE_H3K27ac_heatmapTSS.pdf", outFile = "E11.5_ENCFF512SFE_H3K27ac_annotation.txt",  GOenrich = "E11.5_ENCFF512SFE_H3K27ac_mm10GOenrich.txt", kegg="E11.5_ENCFF512SFE_H3K27ac_KEGG.txt")
annotatePeaksmm10(peak = "ENCFF515PKL_vs_ENCFF376FGM_E11.5_H3K27ac_macs2_peaks.narrowPeak", annoBar = "E11.5_ENCFF515PKL_H3K27ac_annoBar.pdf", distanceTSS = "E11.5_ENCFF515PKL_H3K27ac_distanceTSS.pdf", heatmapTSS = "E11.5_ENCFF515PKL_H3K27ac_heatmapTSS.pdf", outFile = "E11.5_ENCFF515PKL_H3K27ac_annotation.txt",  GOenrich = "E11.5_ENCFF515PKL_H3K27ac_mm10GOenrich.txt", kegg="E11.5_ENCFF515PKL_H3K27ac_KEGG.txt")
annotatePeaksmm10(peak = "ENCFF011NFM_vs_ENCFF058AUT_E12.5_H3K27ac_macs2_peaks.narrowPeak", annoBar = "E12.5_ENCFF011NFM_H3K27ac_annoBar.pdf", distanceTSS = "E12.5_ENCFF011NFM_H3K27ac_distanceTSS.pdf", heatmapTSS = "E12.5_ENCFF011NFM_H3K27ac_heatmapTSS.pdf", outFile = "E12.5_ENCFF011NFM_H3K27ac_annotation.txt",  GOenrich = "E12.5_ENCFF011NFM_H3K27ac_mm10GOenrich.txt", kegg="E12.5_ENCFF011NFM_H3K27ac_KEGG.txt")
annotatePeaksmm10(peak = "ENCFF394TZN_vs_ENCFF203JQV_E12.5_H3K27ac_macs2_peaks.narrowPeak", annoBar = "E12.5_ENCFF394TZN_H3K27ac_annoBar.pdf", distanceTSS = "E12.5_ENCFF394TZN_H3K27ac_distanceTSS.pdf", heatmapTSS = "E12.5_ENCFF394TZN_H3K27ac_heatmapTSS.pdf", outFile = "E12.5_ENCFF394TZN_H3K27ac_annotation.txt",  GOenrich = "E12.5_ENCFF394TZN_H3K27ac_mm10GOenrich.txt", kegg="E12.5_ENCFF394TZN_H3K27ac_KEGG.txt")
annotatePeaksmm10(peak = "ENCFF194ORC_vs_ENCFF117QRC_E13.5_H3K27ac_macs2_peaks.narrowPeak", annoBar = "E13.5_ENCFF194ORC_H3K27ac_annoBar.pdf", distanceTSS = "E13.5_ENCFF194ORC_H3K27ac_distanceTSS.pdf", heatmapTSS = "E13.5_ENCFF194ORC_H3K27ac_heatmapTSS.pdf", outFile = "E13.5_ENCFF194ORC_H3K27ac_annotation.txt",  GOenrich = "E13.5_ENCFF194ORC_H3K27ac_mm10GOenrich.txt", kegg="E13.5_ENCFF194ORC_H3K27ac_KEGG.txt")
annotatePeaksmm10(peak = "ENCFF290ZNF_vs_ENCFF248PGK_E13.5_H3K27ac_macs2_peaks.narrowPeak", annoBar = "E13.5_ENCFF290ZNF_H3K27ac_annoBar.pdf", distanceTSS = "E13.5_ENCFF290ZNF_H3K27ac_distanceTSS.pdf", heatmapTSS = "E13.5_ENCFF290ZNF_H3K27ac_heatmapTSS.pdf", outFile = "E13.5_ENCFF290ZNF_H3K27ac_annotation.txt",  GOenrich = "E13.5_ENCFF290ZNF_H3K27ac_mm10GOenrich.txt", kegg="E13.5_ENCFF290ZNF_H3K27ac_KEGG.txt")
annotatePeaksmm10(peak = "ENCFF902HAR_vs_ENCFF002HZV_E14.5_H3K27ac_macs2_peaks.narrowPeak", annoBar = "E14.5_ENCFF902HAR_H3K27ac_annoBar.pdf", distanceTSS = "E14.5_ENCFF902HAR_H3K27ac_distanceTSS.pdf", heatmapTSS = "E14.5_ENCFF902HAR_H3K27ac_heatmapTSS.pdf", outFile = "E14.5_ENCFF902HAR_H3K27ac_annotation.txt",   GOenrich = "E14.5_ENCFF902HAR_H3K27ac_mm10GOenrich.txt", kegg="E14.5_ENCFF902HAR_H3K27ac_KEGG.txt")
annotatePeaksmm10(peak = "ENCFF327VAO_vs_ENCFF784ORI_E14.5_H3K27ac_macs2_peaks.narrowPeak", annoBar = "E14.5_ENCFF327VAO_H3K27ac_annoBar.pdf", distanceTSS = "E14.5_ENCFF327VAO_H3K27ac_distanceTSS.pdf", heatmapTSS = "E14.5_ENCFF327VAO_H3K27ac_heatmapTSS.pdf", outFile = "E14.5_ENCFF327VAO_H3K27ac_annotation.txt",   GOenrich = "E14.5_ENCFF327VAO_H3K27ac_mm10GOenrich.txt", kegg="E14.5_ENCFF327VAO_H3K27ac_KEGG.txt")
annotatePeaksmm10(peak = "ENCFF584JFB_vs_ENCFF727QTS_E15.5_H3K27ac_macs2_peaks.narrowPeak", annoBar = "E15.5_ENCFF584JFB_H3K27ac_annoBar.pdf", distanceTSS = "E15.5_ENCFF584JFB_H3K27ac_distanceTSS.pdf", heatmapTSS = "E15.5_ENCFF584JFB_H3K27ac_heatmapTSS.pdf", outFile = "E15.5_ENCFF584JFB_H3K27ac_annotation.txt",   GOenrich = "E15.5_ENCFF584JFB_H3K27ac_mm10GOenrich.txt", kegg="E15.5_ENCFF584JFB_H3K27ac_KEGG.txt")
annotatePeaksmm10(peak = "ENCFF707WKL_vs_ENCFF182XFG_E15.5_H3K27ac_macs2_peaks.narrowPeak", annoBar = "E15.5_ENCFF707WKL_H3K27ac_annoBar.pdf", distanceTSS = "E15.5_ENCFF707WKL_H3K27ac_distanceTSS.pdf", heatmapTSS = "E15.5_ENCFF707WKL_H3K27ac_heatmapTSS.pdf", outFile = "E15.5_ENCFF707WKL_H3K27ac_annotation.txt",  GOenrich = "E15.5_ENCFF707WKL_H3K27ac_mm10GOenrich.txt", kegg="E15.5_ENCFF707WKL_H3K27ac_KEGG.txt")

setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/replicates/H3K4me3/")
annotatePeaksmm10(peak = "ENCFF124UYX_vs_ENCFF157KEH_E10.5_H3K4me3_macs2_peaks.narrowPeak", annoBar = "E10.5_ENCFF124UYX_H3K4me3_annoBar.pdf", distanceTSS = "E10.5_ENCFF124UYX_H3K4me3_distanceTSS.pdf", heatmapTSS = "E10.5_ENCFF124UYX_H3K4me3_heatmapTSS.pdf", outFile = "E10.5_ENCFF124UYX_H3K4me3_annotation.txt",  GOenrich = "E10.5_ENCFF124UYX_H3K4me3_mm10GOenrich.txt", kegg="E10.5_ENCFF124UYX_H3K4me3_KEGG.txt")
annotatePeaksmm10(peak = "ENCFF045IPK_vs_ENCFF825AVI_E10.5_H3K4me3_macs2_peaks.narrowPeak", annoBar = "E10.5_ENCFF045IPK_H3K4me3_annoBar.pdf", distanceTSS = "E10.5_ENCFF045IPK_H3K4me3_distanceTSS.pdf", heatmapTSS = "E10.5_ENCFF045IPK_H3K4me3_heatmapTSS.pdf", outFile = "E10.5_ENCFF045IPK_H3K4me3_annotation.txt",   GOenrich = "E10.5_ENCFF045IPK_H3K4me3_mm10GOenrich.txt", kegg="E10.5_ENCFF045IPK_H3K4me3_KEGG.txt")
annotatePeaksmm10(peak = "ENCFF717QDV_vs_ENCFF376FGM_E11.5_H3K4me3_macs2_peaks.narrowPeak", annoBar = "E11.5_ENCFF717QDV_H3K4me3_annoBar.pdf", distanceTSS = "E11.5_ENCFF717QDV_H3K4me3_distanceTSS.pdf", heatmapTSS = "E11.5_ENCFF717QDV_H3K4me3_heatmapTSS.pdf", outFile = "E11.5_ENCFF717QDV_H3K4me3_annotation.txt",   GOenrich = "E11.5_ENCFF717QDV_H3K4me3_mm10GOenrich.txt", kegg="E11.5_ENCFF717QDV_H3K4me3_KEGG.txt")
annotatePeaksmm10(peak = "ENCFF760QYZ_vs_ENCFF184CUE_E11.5_H3K4me3_macs2_peaks.narrowPeak", annoBar = "E11.5_ENCFF760QYZ_H3K4me3_annoBar.pdf", distanceTSS = "E11.5_ENCFF760QYZ_H3K4me3_distanceTSS.pdf", heatmapTSS = "E11.5_ENCFF760QYZ_H3K4me3_heatmapTSS.pdf", outFile = "E11.5_ENCFF760QYZ_H3K4me3_annotation.txt", GOenrich = "E11.5_ENCFF515PKL_H3K4me3_mm10GOenrich.txt", kegg="E11.5_ENCFF515PKL_H3K4me3_KEGG.txt")
annotatePeaksmm10(peak = "ENCFF182ZPF_vs_ENCFF203JQV_E12.5_H3K4me3_macs2_peaks.narrowPeak", annoBar = "E12.5_ENCFF182ZPF_H3K4me3_annoBar.pdf", distanceTSS = "E12.5_ENCFF182ZPF_H3K4me3_distanceTSS.pdf", heatmapTSS = "E12.5_ENCFF182ZPF_H3K4me3_heatmapTSS.pdf", outFile = "E12.5_ENCFF182ZPF_H3K4me3_annotation.txt",  GOenrich = "E12.5_ENCFF182ZPF_H3K4me3_mm10GOenrich.txt", kegg="E12.5_ENCFF182ZPF_H3K4me3_KEGG.txt")
annotatePeaksmm10(peak = "ENCFF941QJZ_vs_ENCFF058AUT_E12.5_H3K4me3_macs2_peaks.narrowPeak", annoBar = "E12.5_ENCFF941QJZ_H3K4me3_annoBar.pdf", distanceTSS = "E12.5_ENCFF941QJZ_H3K4me3_distanceTSS.pdf", heatmapTSS = "E12.5_ENCFF941QJZ_H3K4me3_heatmapTSS.pdf", outFile = "E12.5_ENCFF941QJZ_H3K4me3_annotation.txt",   GOenrich = "E12.5_ENCFF941QJZ_H3K4me3_mm10GOenrich.txt", kegg="E12.5_ENCFF941QJZ_H3K4me3_KEGG.txt")
annotatePeaksmm10(peak = "ENCFF124TAB_vs_ENCFF248PGK_E13.5_H3K4me3_macs2_peaks.narrowPeak", annoBar = "E13.5_ENCFF124TAB_H3K4me3_annoBar.pdf", distanceTSS = "E13.5_ENCFF124TAB_H3K4me3_distanceTSS.pdf", heatmapTSS = "E13.5_ENCFF124TAB_H3K4me3_heatmapTSS.pdf", outFile = "E13.5_ENCFF124TAB_H3K4me3_annotation.txt",   GOenrich = "E13.5_ENCFF124TAB_H3K4me3_mm10GOenrich.txt", kegg="E13.5_ENCFF124TAB_H3K4me3_KEGG.txt")
annotatePeaksmm10(peak = "ENCFF485UDC_vs_ENCFF117QRC_E13.5_H3K4me3_macs2_peaks.narrowPeak", annoBar = "E13.5_ENCFF485UDC_H3K4me3_annoBar.pdf", distanceTSS = "E13.5_ENCFF485UDC_H3K4me3_distanceTSS.pdf", heatmapTSS = "E13.5_ENCFF485UDC_H3K4me3_heatmapTSS.pdf", outFile = "E13.5_ENCFF485UDC_H3K4me3_annotation.txt", GOenrich = "E13.5_ENCFF485UDC_H3K4me3_mm10GOenrich.txt", kegg="E13.5_ENCFF485UDC_H3K4me3_KEGG.txt")
annotatePeaksmm10(peak = "ENCFF665QBJ_vs_ENCFF002HZV_E14.5_H3K4me3_macs2_peaks.narrowPeak", annoBar = "E14.5_ENCFF665QBJ_H3K4me3_annoBar.pdf", distanceTSS = "E14.5_ENCFF665QBJ_H3K4me3_distanceTSS.pdf", heatmapTSS = "E14.5_ENCFF665QBJ_H3K4me3_heatmapTSS.pdf", outFile = "E14.5_ENCFF665QBJ_H3K4me3_annotation.txt",   GOenrich = "E14.5_ENCFF665QBJ_H3K4me3_mm10GOenrich.txt", kegg="E14.5_ENCFF665QBJ_H3K4me3_KEGG.txt")
annotatePeaksmm10(peak = "ENCFF724DMU_vs_ENCFF784ORI_E14.5_H3K4me3_macs2_peaks.narrowPeak", annoBar = "E14.5_ENCFF724DMU_H3K4me3_annoBar.pdf", distanceTSS = "E14.5_ENCFF724DMU_H3K4me3_distanceTSS.pdf", heatmapTSS = "E14.5_ENCFF724DMU_H3K4me3_heatmapTSS.pdf", outFile = "E14.5_ENCFF724DMU_H3K4me3_annotation.txt",  GOenrich = "E14.5_ENCFF724DMU_H3K4me3_mm10GOenrich.txt", kegg="E14.5_ENCFF724DMU_H3K4me3_KEGG.txt")
annotatePeaksmm10(peak = "ENCFF258KCR_vs_ENCFF727QTS_E15.5_H3K4me3_macs2_peaks.narrowPeak", annoBar = "E15.5_ENCFF258KCR_H3K4me3_annoBar.pdf", distanceTSS = "E15.5_ENCFF258KCR_H3K4me3_distanceTSS.pdf", heatmapTSS = "E15.5_ENCFF258KCR_H3K4me3_heatmapTSS.pdf", outFile = "E15.5_ENCFF258KCR_H3K4me3_annotation.txt",  GOenrich = "E15.5_ENCFF258KCR_H3K4me3_mm10GOenrich.txt", kegg="E15.5_ENCFF258KCR_H3K4me3_KEGG.txt")
annotatePeaksmm10(peak = "ENCFF401BKM_vs_ENCFF182XFG_E15.5_H3K4me3_macs2_peaks.narrowPeak", annoBar = "E15.5_ENCFF401BKM_H3K4me3_annoBar.pdf", distanceTSS = "E15.5_ENCFF401BKM_H3K4me3_distanceTSS.pdf", heatmapTSS = "E15.5_ENCFF401BKM_H3K4me3_heatmapTSS.pdf", outFile = "E15.5_ENCFF401BKM_H3K4me3_annotation.txt",   GOenrich = "E15.5_ENCFF401BKM_H3K4me3_mm10GOenrich.txt", kegg="E15.5_ENCFF401BKM_H3K4me3_KEGG.txt")

## Overlaping dunnart and mouse peaks
setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/")
annotatePeaksmm10(peak = "enhancer_summit100bp_mm10TOsmiCra1_smiCraTOmm10.bed", outFile = "enhancer_summit100bp_mm10TOsmiCra1_smiCraTOmm10_annotation.txt", annoBar = "enhancer_summit100bp_mm10TOsmiCra1_smiCraTOmm10_annoBar.pdf", distanceTSS = "enhancer_summit100bp_mm10TOsmiCra1_smiCraTOmm10_distanceTSS.pdf", heatmapTSS = "enhancer_summit100bp_mm10TOsmiCra1_smiCraTOmm10_heatmapTSS.pdf", GOenrich = "enhancer_summit100bp_mm10TOsmiCra1_smiCraTOmm10_mm10GOenrich", kegg="enhancer_summit100bp_mm10TOsmiCra1_smiCraTOmm10_KEGG.txt")
annotatePeaksmm10(peak = "promoter_summit100bp_mm10TOsmiCra1_smiCraTOmm10.bed", outFile = "promoter_summit100bp_mm10TOsmiCra1_smiCraTOmm10_annotation.txt", annoBar = "promoter_summit100bp_mm10TOsmiCra1_smiCraTOmm10_annoBar.pdf", distanceTSS = "promoter_summit100bp_mm10TOsmiCra1_smiCraTOmm10_distanceTSS.pdf", heatmapTSS = "promoter_summit100bp_mm10TOsmiCra1_smiCraTOmm10_heatmapTSS.pdf", GOenrich = "promoter_summit100bp_mm10TOsmiCra1_smiCraTOmm10_mm10GOenrich", kegg="promoter_summit100bp_mm10TOsmiCra1_smiCraTOmm10_KEGG.txt")
enh <- read.table("enhancer_summit100bp_mm10TOsmiCra1_smiCraTOmm10_annotation.txt", sep="\t", header=TRUE, quote = "")
pro <- read.table("promoter_summit100bp_mm10TOsmiCra1_smiCraTOmm10_annotation.txt", sep="\t", header=TRUE, quote = "")

setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/overlaps/enhancers/")
annotatePeaksmm10(peak = "E10.5_enhancerOverlap_100bpsummits.bed", outFile = "E10.5_enhancer_annotation.txt", annoBar = "E10.5_enhancer_annoBar.pdf", distanceTSS = "E10.5_enhancer_distanceTSS.pdf", heatmapTSS = "E10.5_enhancer_heatmapTSS.pdf",  outFile1 = "E10.5_enhancer_annotationConvertedIDs.txt" , GOenrich = "E10.5_enhancer_mm10GOenrich", kegg="E10.5_enhancer_KEGG.txt")
annotatePeaksmm10(peak = "E11.5_enhancerOverlap_100bpsummits.bed", outFile = "E11.5_enhancer_annotation.txt", annoBar = "E11.5_enhancer_annoBar.pdf", distanceTSS = "E11.5_enhancer_distanceTSS.pdf", heatmapTSS = "E11.5_enhancer_heatmapTSS.pdf",  outFile1 = "E11.5_enhancer_annotationConvertedIDs.txt" , GOenrich = "E11.5_enhancer_mm10GOenrich", kegg="E11.5_enhancer_KEGG.txt")
annotatePeaksmm10(peak = "E12.5_enhancerOverlap_100bpsummits.bed", outFile = "E12.5_enhancer_annotation.txt", annoBar = "E12.5_enhancer_annoBar.pdf", distanceTSS = "E12.5_enhancer_distanceTSS.pdf", heatmapTSS = "E12.5_enhancer_heatmapTSS.pdf",  outFile1 = "E12.5_enhancer_annotationConvertedIDs.txt" , GOenrich = "E12.5_enhancer_mm10GOenrich", kegg="E12.5_enhancer_KEGG.txt")
annotatePeaksmm10(peak = "E13.5_enhancerOverlap_100bpsummits.bed", outFile = "E13.5_enhancer_annotation.txt", annoBar = "E13.5_enhancer_annoBar.pdf", distanceTSS = "E13.5_enhancer_distanceTSS.pdf", heatmapTSS = "E13.5_enhancer_heatmapTSS.pdf",  outFile1 = "E13.5_enhancer_annotationConvertedIDs.txt" , GOenrich = "E13.5_enhancer_mm10GOenrich", kegg="E13.5_enhancer_KEGG.txt")
annotatePeaksmm10(peak = "E14.5_enhancerOverlap_100bpsummits.bed", outFile = "E14.5_enhancer_annotation.txt", annoBar = "E14.5_enhancer_annoBar.pdf", distanceTSS = "E14.5_enhancer_distanceTSS.pdf", heatmapTSS = "E14.5_enhancer_heatmapTSS.pdf",  outFile1 = "E14.5_enhancer_annotationConvertedIDs.txt" , GOenrich = "E14.5_enhancer_mm10GOenrich", kegg="E14.5_enhancer_KEGG.txt")
annotatePeaksmm10(peak = "E15.5_enhancerOverlap_100bpsummits.bed", outFile = "E15.5_enhancer_annotation.txt", annoBar = "E15.5_enhancer_annoBar.pdf", distanceTSS = "E15.5_enhancer_distanceTSS.pdf", heatmapTSS = "E15.5_enhancer_heatmapTSS.pdf",  outFile1 = "E15.5_enhancer_annotationConvertedIDs.txt" , GOenrich = "E15.5_enhancer_mm10GOenrich", kegg="E15.5_enhancer_KEGG.txt")

setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/overlaps/promoters/")
annotatePeaksmm10(peak = "E10.5_promoterOverlap_100bpsummits.bed", outFile = "E10.5_promoter_annotation.txt", annoBar = "E10.5_promoter_annoBar.pdf", distanceTSS = "E10.5_promoter_distanceTSS.pdf", heatmapTSS = "E10.5_promoter_heatmapTSS.pdf",  outFile1 = "E10.5_promoter_annotationConvertedIDs.txt" , GOenrich = "E10.5_promoter_mm10GOenrich", kegg="E10.5_promoter_KEGG.txt")
annotatePeaksmm10(peak = "E11.5_promoterOverlap_100bpsummits.bed", outFile = "E11.5_promoter_annotation.txt", annoBar = "E11.5_promoter_annoBar.pdf", distanceTSS = "E11.5_promoter_distanceTSS.pdf", heatmapTSS = "E11.5_promoter_heatmapTSS.pdf",  outFile1 = "E11.5_promoter_annotationConvertedIDs.txt" , GOenrich = "E11.5_promoter_mm10GOenrich", kegg="E11.5_promoter_KEGG.txt")
annotatePeaksmm10(peak = "E12.5_promoterOverlap_100bpsummits.bed", outFile = "E12.5_promoter_annotation.txt", annoBar = "E12.5_promoter_annoBar.pdf", distanceTSS = "E12.5_promoter_distanceTSS.pdf", heatmapTSS = "E12.5_promoter_heatmapTSS.pdf",  outFile1 = "E12.5_promoter_annotationConvertedIDs.txt" , GOenrich = "E12.5_promoter_mm10GOenrich", kegg="E12.5_promoter_KEGG.txt")
annotatePeaksmm10(peak = "E13.5_promoterOverlap_100bpsummits.bed", outFile = "E13.5_promoter_annotation.txt", annoBar = "E13.5_promoter_annoBar.pdf", distanceTSS = "E13.5_promoter_distanceTSS.pdf", heatmapTSS = "E13.5_promoter_heatmapTSS.pdf",  outFile1 = "E13.5_promoter_annotationConvertedIDs.txt" , GOenrich = "E13.5_promoter_mm10GOenrich", kegg="E13.5_promoter_KEGG.txt")
annotatePeaksmm10(peak = "E14.5_promoterOverlap_100bpsummits.bed", outFile = "E14.5_promoter_annotation.txt", annoBar = "E14.5_promoter_annoBar.pdf", distanceTSS = "E14.5_promoter_distanceTSS.pdf", heatmapTSS = "E14.5_promoter_heatmapTSS.pdf",  outFile1 = "E14.5_promoter_annotationConvertedIDs.txt" , GOenrich = "E14.5_promoter_mm10GOenrich", kegg="E14.5_promoter_KEGG.txt")
annotatePeaksmm10(peak = "E15.5_promoterOverlap_100bpsummits.bed", outFile = "E15.5_promoter_annotation.txt", annoBar = "E15.5_promoter_annoBar.pdf", distanceTSS = "E15.5_promoter_distanceTSS.pdf", heatmapTSS = "E15.5_promoter_heatmapTSS.pdf",  outFile1 = "E15.5_promoter_annotationConvertedIDs.txt" , GOenrich = "E15.5_promoter_mm10GOenrich", kegg="E15.5_promoter_KEGG.txt")

## No overlaps
setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/overlaps/enhancers/")
annotatePeaksmm10(peak = "E10.5_enhancerNoOverlap_100bpsummits.bed", outFile = "E10.5_enhancerNo_annotation.txt", annoBar = "E10.5_enhancerNo_annoBar.pdf", distanceTSS = "E10.5_enhancerNo_distanceTSS.pdf", heatmapTSS = "E10.5_enhancerNo_heatmapTSS.pdf",  GOenrich = "E10.5_enhancerNo_mm10GOenrich", kegg="E10.5_enhancerNo_KEGG.txt")
annotatePeaksmm10(peak = "E11.5_enhancerNoOverlap_100bpsummits.bed", outFile = "E11.5_enhancerNo_annotation.txt", annoBar = "E11.5_enhancerNo_annoBar.pdf", distanceTSS = "E11.5_enhancerNo_distanceTSS.pdf", heatmapTSS = "E11.5_enhancerNo_heatmapTSS.pdf",  GOenrich = "E11.5_enhancerNo_mm10GOenrich", kegg="E11.5_enhancerNo_KEGG.txt")
annotatePeaksmm10(peak = "E12.5_enhancerNoOverlap_100bpsummits.bed", outFile = "E12.5_enhancerNo_annotation.txt", annoBar = "E12.5_enhancerNo_annoBar.pdf", distanceTSS = "E12.5_enhancerNo_distanceTSS.pdf", heatmapTSS = "E12.5_enhancerNo_heatmapTSS.pdf",   GOenrich = "E12.5_enhancerNo_mm10GOenrich", kegg="E12.5_enhancerNo_KEGG.txt")
annotatePeaksmm10(peak = "E13.5_enhancerNoOverlap_100bpsummits.bed", outFile = "E13.5_enhancerNo_annotation.txt", annoBar = "E13.5_enhancerNo_annoBar.pdf", distanceTSS = "E13.5_enhancerNo_distanceTSS.pdf", heatmapTSS = "E13.5_enhancerNo_heatmapTSS.pdf",  GOenrich = "E13.5_enhancerNo_mm10GOenrich", kegg="E13.5_enhancerNo_KEGG.txt")
annotatePeaksmm10(peak = "E14.5_enhancerNoOverlap_100bpsummits.bed", outFile = "E14.5_enhancerNo_annotation.txt", annoBar = "E14.5_enhancerNo_annoBar.pdf", distanceTSS = "E14.5_enhancerNo_distanceTSS.pdf", heatmapTSS = "E14.5_enhancerNo_heatmapTSS.pdf",  GOenrich = "E14.5_enhancerNo_mm10GOenrich", kegg="E14.5_enhancerNo_KEGG.txt")
annotatePeaksmm10(peak = "E15.5_enhancerNoOverlap_100bpsummits.bed", outFile = "E15.5_enhancerNo_annotation.txt", annoBar = "E15.5_enhancerNo_annoBar.pdf", distanceTSS = "E15.5_enhancerNo_distanceTSS.pdf", heatmapTSS = "E15.5_enhancerNo_heatmapTSS.pdf",  GOenrich = "E15.5_enhancerNo_mm10GOenrich", kegg="E15.5_enhancerNo_KEGG.txt")

setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/overlaps/promoters/")
annotatePeaksmm10(peak = "E10.5_promoterNoOverlap_100bpsummits.bed", outFile = "E10.5_promoterNo_annotation.txt", annoBar = "E10.5_promoterNo_annoBar.pdf", distanceTSS = "E10.5_promoterNo_distanceTSS.pdf", heatmapTSS = "E10.5_promoterNo_heatmapTSS.pdf",  GOenrich = "E10.5_promoterNo_mm10GOenrich", kegg="E10.5_promoterNo_KEGG.txt")
annotatePeaksmm10(peak = "E11.5_promoterNoOverlap_100bpsummits.bed", outFile = "E11.5_promoterNo_annotation.txt", annoBar = "E11.5_promoterNo_annoBar.pdf", distanceTSS = "E11.5_promoterNo_distanceTSS.pdf", heatmapTSS = "E11.5_promoterNo_heatmapTSS.pdf",   GOenrich = "E11.5_promoterNo_mm10GOenrich", kegg="E11.5_promoterNo_KEGG.txt")
annotatePeaksmm10(peak = "E12.5_promoterNoOverlap_100bpsummits.bed", outFile = "E12.5_promoterNo_annotation.txt", annoBar = "E12.5_promoterNo_annoBar.pdf", distanceTSS = "E12.5_promoterNo_distanceTSS.pdf", heatmapTSS = "E12.5_promoterNo_heatmapTSS.pdf",  GOenrich = "E12.5_promoterNo_mm10GOenrich", kegg="E12.5_promoterNo_KEGG.txt")
annotatePeaksmm10(peak = "E13.5_promoterNoOverlap_100bpsummits.bed", outFile = "E13.5_promoterNo_annotation.txt", annoBar = "E13.5_promoterNo_annoBar.pdf", distanceTSS = "E13.5_promoterNo_distanceTSS.pdf", heatmapTSS = "E13.5_promoterNo_heatmapTSS.pdf", GOenrich = "E13.5_promoterNo_mm10GOenrich", kegg="E13.5_promoterNo_KEGG.txt")
annotatePeaksmm10(peak = "E14.5_promoterNoOverlap_100bpsummits.bed", outFile = "E14.5_promoterNo_annotation.txt", annoBar = "E14.5_promoterNo_annoBar.pdf", distanceTSS = "E14.5_promoterNo_distanceTSS.pdf", heatmapTSS = "E14.5_promoterNo_heatmapTSS.pdf",  GOenrich = "E14.5_promoterNo_mm10GOenrich", kegg="E14.5_promoterNo_KEGG.txt")
annotatePeaksmm10(peak = "E15.5_promoterNoOverlap_100bpsummits.bed", outFile = "E15.5_promoterNo_annotation.txt", annoBar = "E15.5_promoterNo_annoBar.pdf", distanceTSS = "E15.5_promoterNo_distanceTSS.pdf", heatmapTSS = "E15.5_promoterNo_heatmapTSS.pdf",   GOenrich = "E15.5_promoterNo_mm10GOenrich", kegg="E15.5_promoterNo_KEGG.txt")

## OVERLAP NEAREST GENE CALLS

# Enhancers
# E10.5, E11.5, E12.5, E13.5, E14.5, E15.5 and dunnart P0
# Needs to be for the orthologous gene calls so use the convertedIDs file and filter for peaks that have an orthologous gene ID
# use lapply to make a list of all the nearest gene calls into one 
setwd("/Users/lauracook/OneDrive - The University of Melbourne/PhD (2018-2021)/6-ChIPseq/3-DataAnalysis/2-CrossSpecies/4-Peaks/2-DunnartSubsample10Mreads/")

samplefiles1 <- list.files("4-ConvertedIDs/1-Enhancers/", pattern= ".txt", full.names=T)
samplefiles1 <- as.list(samplefiles1)
names(samplefiles1) <- c("dunnart", "E15.5")
data <- lapply(samplefiles1, function(x) read.table(x, header=TRUE, sep="\t", quote = ""))
genes= lapply(data, function(x) unique(na.omit(as.data.frame(x)$mouseensembl)))
vennplot(genes)


# also look at conservation for regions that are both active versus those that aren't
# what gene pathways are the ones that are active enriched for?
# motif enrichment?

## JACCARD INDEX 
jaccard <- function(a, b) {
    a <- scan(a, what="", sep="\n")
    b <- scan(b, what="", sep="\n")
    intersection = length(intersect(a, b))
    union = length(a) + length(b) - intersection
    return (intersection/union)
}

## Compare GO terms
setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/consensus/enhancers/")
jaccard(a="dunnart_enhancer_mm10GOenrich_GOids.txt", b="E10.5_enhancer_mm10GOenrich_GOids.txt")

setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/consensus/promoters/")
jaccard(a="dunnart_promoter_mm10GOenrich_GOids.txt", b="E15.5_promoter_mm10GOenrich_GOids.txt")

## Compare gene lists
setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/consensus/enhancers/")
jaccard(a="dunnart_enhancer_geneId.txt", b="E15.5_enhancer_geneId.txt")

setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/consensus/promoters/")
jaccard(a="dunnart_promoter_geneId.txt", b="E10.5_promoter_geneId.txt")


